Changelog
=========

Notable changes between releases.

0.1.2 (?)
------------------

**Features**

* Provide a repository abstraction
* Support the Git command's simplest subcommands (clone, update)
* Support Github and Bitbucket hosts
* Provide a utility to map between import paths and repositories

0.1.1 (2014-06-08)
-------------------

* Fix Repository create -> clone command delegation
* Add uninstall notes to README
* Add version.py single-source version getter module

0.1.0 (2014-06-01)
-------------------

* Initial commit
